# rex

## clean

python setup.py sdist

## release

python setup.py upload --verbose

## install

pip intall rext

## upgrade

pip install --upgrade rext

## list

pip list

## import

from rext import mstring as ms

## use

print(ms.remove_space_all("666 666"))
